Crate rama_tls

Crate rama_tls 

TLS implementations for Rama.

Rama

Crate used by the end-user rama crate and rama crate authors alike.

Learn more about rama:

Modules

boringboring
boring based TLS support for rama.
keylog
Keylog facility used by any tls implementation supported by rama, and which can be used for your owns as well.
types
common tls types